globals [
  centre                ; central patch, where lobbies and reference groups are located
  city                  ; set of patches with land use = "city"; densely populated; preferred by high-tech workers
  village               ; set of patches with land use = "village"; less densely populated; preferred by agri complex workers
  countryside           ; set of patches with land use = "country"; initially 1 farm per patch; rich families may migrate to abandoned farms
  norms-list            ; list of strings decribing the behavioural norms
  length-norms-list     ; number of items in the norms list
  labor-market-running  ; indicates (true/false) if the labor market procedure (to run-labor-market) is currently operating
  index-base            ; base value for economy index
  max-lobby-support     ; sum of individuals' economic relevance for computing lobby strength

;labor market statistics:
  current-agri-workers
  agri-employment
  current-tech-workers
  tech-employment
  number-of-unemployed
  emigrated-high-tech-employees
  total-high-tech-emigration

;reference-groups (abstract groups of individuals who act according to a common set of norms):
  farmers
  countryside-criminals
  agri-workers
  high-tech-workers
  unemployed
  villagers
  urbanites
  commuters
  patients
  locally-involved
  globally-involved
  animal-welfare
  employment
  public-administration

;lobbies (abstract actors who try and affect opinions of other actors)
  livestock-lobby
  high-tech-lobby
  global-responsibility-lobby
  local-responsibility-lobby

;livestock farming variables:
  current-production-cost
  manure-factor
  bad-air-factor
  infection-factor
  current-pig-price
  available-farm-estates
  annual-pig-production
  annual-manure-production
  current-infection-strength
  mean-production-capacity
  pig-production-growth

;public administration policy variables:
  number-of-parties
  frozen-licensed-capacity
  licence-available
  total-licensed-capacity

;statistics
  public-opinion
  farms
  annual_production
  farm_income
  agri_employment
  tech_employment
  total_tech_emigration
]

patches-own [
  land-use            ; type of patch, one of {"centre", "city", "village", "country"}
  cost-of-living      ; cost of living per tick at this patch
  air-pollution       ; level of bad air at this patch
  infection-risk      ; infection probability per tick when visiting this patch or living here
  livestock-allowed   ; boolean, whether or not local regulations allow keeping of livestock here
  brown-area          ; boolean, whether or not environmental conditions on this patch or any neighbors are bad
  patients-here       ; boolean, whether or not any patients live on this patch
  patients-around     ; boolean, whether or not any patients live in the neighborhood
]

breed [individuals individual]            ; an individual agent represents an actor who produces flows and may be affected by flows
breed [reference-groups reference-group]  ; a reference-group agent represents a group of individuals sharing a common set of norms
breed [political-parties political-party] ; a political-party agent has a say in public policy, weighed by the number of votes
breed [lobbies lobby]                     ; a lobby agent represents a social movement supporting or opposing particular norms

turtles-own [
  actor-type                        ; string describing the nature of the agent, e.g. "political party", "livestock lobby", "born farmer"
]

individuals-own [
  reference-group-memberships       ; list of reference-groups
  norms                ; list of norms respected by the agent
  opinions             ; list of real values [0 ... 1] corresponding to the norms list; 1 means full support, 0.5: indifferent
  stability            ; inclination to compromise in opinion dynamics
  basic-uncertainty    ; agent characteristic for intitialization of uncertainties lists
  uncertainties-pro    ; list of real values correponding to the opinions, used in the opinion dynamics
  uncertainties-contra ; list of real values correponding to the opinions, used in the opinion dynamics
  cash                 ; amount of money available for cost of living and investments
  salary               ; income from salary per tick; relevant for industry workers; 0 otherwise
  production-capacity  ; number of anmimals produced per tick; relevant for farmers; 0 otherwise
  licensed-capacity    ; licenced number of anmimals to be produced per tick; relevant only if licence-required-for-livestock
  manure-flow          ; measure of the quantity of manure produced per animal per tick
  bad-air-flow         ; measure of the contribution per animal per tick to air polution on the farm and neighboring patces
  infection-flow       ; measure of the contribution per animal per tick to infection risk on the farm and neighboring patces
  farm-income          ; income from farming
  my-party             ; refers to the political party the individual has voted for
  my-party-distance    ; measure for the distance between the party's and the individual's opinions
  lobbies-i-support    ; list of lobbies currently supported by this individual
  quitted-farming      ; flag to indicate that the individual has just quitted farmng and enters the labor market as unemployed
  infected             ; flag to indicate that the individual is infected from a source in livestock keeping
  crim-susceptible     ; true if individual is susceptible to criminal intentions when in financial trouble
  support-high-tech    ; true if high-tech employee puts pressure on management to improve livelihood
]

reference-groups-own [
  norms   ; list of norms to be respected by the members
  members ; agent set of the members, i.e. agents that respect the norms of this reference group
]

political-parties-own [
  local-orientation                 ; 1 means local interest, 0 means cosmopolitan
  social-responsibility-orientation ; 1 means social, 0 means economic orientation
  opinions                          ; represent party programme
  votes                             ; the number of indivuduals who voted for this party
]

lobbies-own [
  support                           ; aggregate earnings of individuals who support the lobby
  strength                          ; real value in [0 ... 1]; strenght of public communications and influence on political parties
  pro-norms                         ; list of norms defended by the lobby
  contra-norms                      ; list of norms contested by the lobby
  opinions                          ; list of values 1 or 0 corresponding to the norms list; 1 means pro, 0 means contra
  local-orientation                 ; 1 means local interest, 0 means cosmopolitan
  social-responsibility-orientation ; 1 means social, 0 means economic orientation
]

to DEFAULT ;; values of parameters to be set in the user interface; to be checked
  set simulation-time 50
; PIG PRODUCTION
  set mean-initial-capacity 500
  set price-upper-bound 130
  set price-lower-bound 110
  set initial-input-cost 70
  set investment-cost 200
  set outbreak-frequency 0.04
  set external-policy-effect 0.042
  set criminal-susceptibility 0.0
; AGRI INDUSTRY
  set mean-salary-agri 40000
  set agri-complex-employment 1
; HIGH TECH INDYSTRY
  set mean-salary-tech 50000
  set tech-industry-growth 3.3
; COST OF LIVING
  set country-cost-of-living 30000
  set city-cost-of-living 25000
  set village-cost-of-living 20000
  set farm-estate-value 1000000
; POLITICS
  set auto-politics false
  set not-near-the-city false
  set licence-required-for-livestock false
  set freeze-production-capacity false
  set no-more-licences false
; OPINION DYNAMICS
  set opinion-dynamics-mu 0.2
  set initial-uncertainty-min 0.4
  set initial-uncertainty-max 0.6
  set interaction-partners 2
  set lobby-effectiveness 0.3                     ; susceptibility of political parties to lobbies
  set norm-adoption-threshold 0.83
  set policy-threshold 0.55
  set election-period 4                           ; elections every 4 ticks
; LIVELIHOOD
  set emigration-factor 0.1                       ; fraction of unemployed that emigrate per year
  set bad-air-limit 30000                         ; production capacity above which the neighborhood of a farm is contaminated with bad air
end

to setup
  clear-all
  set manure-factor 1
  set bad-air-factor 1
  set infection-factor outbreak-frequency
  set norms-list [
    "invest in livestock farming";          0
    "care for the local environment";       1
    "care for the global environment";      2
    "foster agri sector";                   3 initial parties opinions:
    "foster high-tech industry";            4   0   1   2   3   4   5   6   7   8   9   10  11  12  13  14  15
    "work in agri industry";                5 [1.0 0.5 0.5 1.0 0.5 0.5 0.5 1.0 1.0 0.5 0.0 0.0 0.0 0.0 0.0 0.5] ; local / economy
    "work in high-tech industry";           6 [0.5 0.5 0.0 0.5 1.0 0.5 0.5 0.5 0.0 0.5 0.5 0.5 0.0 0.0 0.0 0.0] ; global / economy
    "live in the countryside";              7 [0.5 1.0 0.0 1.0 1.0 1.0 1.0 0.5 0.5 0.5 0.5 0.5 0.5 0.0 0.0 1.0] ; local / social
    "live in a village";                    8 [0.0 1.0 1.0 0.0 1.0 0.0 1.0 0.5 0.5 0.5 1.0 0.5 1.0 1.0 0.0 1.0] ; global / social
    "live in the city";                     9
    "licence required for livestock";      10
    "no livestock near populated areas";   11
    "freeze production capacity";          12
    "no more licences";                    13
    "engage in criminal activities";       14
    "don't work";                          15
  ]
  set length-norms-list length norms-list
  set available-farm-estates no-patches
  set current-production-cost initial-input-cost
  set licence-required-for-livestock false
  set licence-available true
  set freeze-production-capacity false
  set no-more-licences false
  set freeze-production-capacity false
  set labor-market-running true
  set centre patch 0 0
  ask centre [
    set land-use "centre"
    set pcolor black
    set livestock-allowed false
    sprout-lobbies 1 [set actor-type "livestock lobby"
      set livestock-lobby self
      set local-orientation 1
      set social-responsibility-orientation 0
      set pro-norms [ 0 3 ]
      set contra-norms [ 10 11 12 13 ]
    ]
    sprout-lobbies 1 [set actor-type "high-tech lobby"
      set high-tech-lobby self
      set local-orientation 0
      set social-responsibility-orientation 0
      set pro-norms [ 1 4 6 11 ]
      set contra-norms [ 14 ]
    ]
    sprout-lobbies 1 [set actor-type "global responsibility lobby"
      set global-responsibility-lobby self
      set local-orientation 0
      set social-responsibility-orientation 1
      set pro-norms [ 1 2 10 12 13 15 ]
      set contra-norms [ 0 3 ]
    ]
    sprout-lobbies 1 [set actor-type "local responsibility lobby"
      set local-responsibility-lobby self
      set local-orientation 1
      set social-responsibility-orientation 1
      set pro-norms [ 1 4 10 11 12 15 ]
      set contra-norms [ 14 ]
    ]
    ask lobbies [
      set shape "house"
      set color grey
      set opinions n-values length-norms-list [0.5]
      foreach pro-norms [pro-norm -> set opinions replace-item pro-norm opinions 1]
      foreach contra-norms [contra-norm -> set opinions replace-item contra-norm opinions 0]
    ]
    sprout-reference-groups 1 [set actor-type "farmers"
      set farmers self
      set norms [0 3 7]
    ]
    sprout-reference-groups 1 [set actor-type "countryside criminals"
      set countryside-criminals self
      set norms [7 14]
    ]
    sprout-reference-groups 1 [set actor-type "agri workers"
      set agri-workers self
      set norms [3 5 ]
    ]
    sprout-reference-groups 1 [set actor-type "high tech workers"
      set high-tech-workers self
      set norms [4 6 ]
    ]
    sprout-reference-groups 1 [set actor-type "unemployed"
      set unemployed self
      set norms [15]
    ]
    sprout-reference-groups 1 [set actor-type "patients"
      set patients self
      set norms [15]
    ]
    sprout-reference-groups 1 [set actor-type "villagers"
      set villagers self
      set norms [8]
    ]
    sprout-reference-groups 1 [set actor-type "urbanites"
      set urbanites self
      set norms [9]
    ]
    sprout-reference-groups 1 [set actor-type "commuters"
      set commuters self
      set norms [7]
    ]
    sprout-reference-groups 1 [set actor-type "locally involved"
      set locally-involved self
      set norms [1]
    ]
    sprout-reference-groups 1 [set actor-type "globally involved"
      set globally-involved self
      set norms [2]
    ]
    sprout-reference-groups 1 [set actor-type "public-administration"
      set public-administration self
      set norms [ ]
    ]
    ask reference-groups [
      set shape "house"
      set color grey
      set members no-turtles
    ]
    sprout-political-parties 1 [set actor-type "political-party" ; b.v.: vvd / d66
      set local-orientation 0
      set social-responsibility-orientation 0
      set opinions [0.5 0.5 0.0 0.5 1.0 0.5 0.5 0.5 0.0 0.5 0.5 0.5 0.0 0.0 0.0 0.0]
    ]
    sprout-political-parties 1 [set actor-type "political-party" ; b.v.: gl / pvdd
      set local-orientation 0
      set social-responsibility-orientation 1
      set opinions [0.0 1.0 1.0 0.0 1.0 0.0 1.0 0.5 0.5 0.5 1.0 0.5 1.0 1.0 0.0 1.0]
    ]
    sprout-political-parties 1 [set actor-type "political-party" ; b.v.: sp / pvda
      set local-orientation 1
      set social-responsibility-orientation 1
      set opinions [0.5 1.0 0.0 1.0 1.0 1.0 1.0 0.5 0.5 0.5 0.5 0.5 0.5 0.0 0.0 1.0]
    ]
    sprout-political-parties 1 [set actor-type "political-party" ; b.v.: cda / lokaal
      set local-orientation 1
      set social-responsibility-orientation 0
      set opinions [1.0 0.5 0.5 1.0 0.5 0.5 0.5 1.0 1.0 0.5 0.0 0.0 0.0 0.0 0.0 0.5]
    ]
    ask political-parties [
      set shape "house"
      set color grey
      set votes 1 ; to avoid division by zero
    ]
    set number-of-parties count political-parties
  ]
  set countryside patches with [not ((abs pxcor < 4) and (abs pycor < 4) or ((abs pxcor > (max-pxcor - 3)) and (abs pycor > (max-pycor - 3))))]
  ask countryside [
    set-patch-country
    sprout-individuals 1
    [ initialise-individual
      set actor-type "born farmer"
      set cash country-cost-of-living + investment-cost * mean-initial-capacity * random-float 2
      try-and-join-reference-group farmers
      set-initial-opinions
    ]
  ]
  set annual-pig-production sum [production-capacity] of [members] of farmers
  ifelse any? [members] of farmers [set mean-production-capacity mean [production-capacity] of [members] of farmers] [set mean-production-capacity 0]
  set village patches with [(abs pxcor > (max-pxcor - 3)) and (abs pycor > (max-pycor - 3))]
  ask village [
    set-patch-village
    sprout-individuals 10
    [ initialise-individual
      set actor-type "born villager"
      try-and-join-reference-group villagers
      try-and-join-reference-group agri-workers
      set-initial-opinions
    ]
  ]
  set current-agri-workers count [members] of agri-workers
  set agri-employment int ((sum [production-capacity] of [members] of farmers) * agri-complex-employment / 1000)
  set city patches with [(abs pxcor < 4) and (abs pycor < 4) and not ((pxcor = 0) and (pycor = 0))]
  ask city [
    set-patch-city
    sprout-individuals 25
    [ initialise-individual
      set actor-type "born urbanite"
      try-and-join-reference-group urbanites
      try-and-join-reference-group high-tech-workers
      set-initial-opinions
    ]
  ]
  set current-tech-workers count [members] of high-tech-workers
  set tech-employment current-tech-workers
  set labor-market-running false
  set index-base sum [salary + production-capacity * ((price-lower-bound + price-lower-bound) / 2 - initial-input-cost)] of individuals
  set emigrated-high-tech-employees 0
  set total-high-tech-emigration 0
  if auto-politics [
    set not-near-the-city false
    set licence-required-for-livestock false
    set freeze-production-capacity false
    set no-more-licences false
  ]
  compute-statistics
  reset-ticks
end ;;setup

to go
  tick                                                                                               ; a tick typicallly represents a year
  generate-external-influences                                                                       ; external influences include market price, national policy, disease outbreak
  ask individuals [ generate-flows ]                                                                 ; individuals decide about their actions based on group norms
  distribute-flows                                                                                   ; aggregated flows and local distributions of effects are computed
  ask individuals [ update-uncertainties ]                                                           ; aggregated flows affect individual's uncertainties about norms
  ask lobbies [ affect-public-opinion ]                                                              ; lobbies communicate their opinions about norms to individuals
  ask reference-groups
  [ exchange-opinions-in-reference-group                                                             ; reference group members exchange opinions on norms
    ;reconsider-norms                                                                                 ; the group's norms may be affected by the discussions; not oprational in present version
  ]
  ask individuals [ reconsider-group-memberships ]                                                   ; individuals reconsider their reference group memberships
  ask lobbies [ affect-political-parties ]                                                           ; lobbies communicate their opinions to political parties
  if 1 = remainder ticks election-period [                                                           ; local government elections are held periodically
    ask political-parties [ set votes 0 ]
    ask individuals [ vote ]                                                                         ; individuals vote for political parties
  ]
  ask public-administration                                                                          ; local public administration
  [ make-policy                                                                                      ;        makes policies, based on parties' opinions and votes
    apply-policy                                                                                     ;        applies policies through coercive norms and licences
  ]
  run-labor-market                                                                                   ; aggregate flows may lead to employment changes
  emigration-and-immigration                                                                         ; external migration due to labor market and environmental conditions
  compute-statistics
  if ticks >= simulation-time [ stop ]                                                               ; the simulation-time parameter is set in the user interface
end

to generate-external-influences ; checked 17-3-2019
  set current-pig-price price-lower-bound + random-float (price-upper-bound - price-lower-bound)     ; random market price for pigs is generated each tick
  set current-production-cost current-production-cost + external-policy-effect * ((price-upper-bound + price-lower-bound) / 2 - current-production-cost); national and EU policies affect production cost
  ifelse outbreak-frequency > random-float 1 [                                                       ; random disease outbreaks are generated
    set current-infection-strength outbreak-frequency
  ][;else
    set current-infection-strength 0
  ]
end

to generate-flows  ;; to be performed by an individual to generate flows based on its norms ; checked 18-09-2019
  set lobbies-i-support [ ]
  if member? 0 norms [;"invest in livestock farming"
    if cash > [cost-of-living] of patch-here [invest-in-pig-production-capacity]
    produce-pigs
  ]
  if member? 1 norms [;""care for the local environment"
    support-lobby local-responsibility-lobby
  ]
  if member? 2 norms [;"care for the global environment"
    support-lobby global-responsibility-lobby
  ]
  if member? 3 norms [;"foster agri sector"
    support-lobby livestock-lobby
  ]
  if member? 4 norms [;"foster high-tech industry"
    if emigrated-high-tech-employees / (tech-employment * tech-industry-growth / 100) > random-float 1 [set support-high-tech true]
    if support-high-tech [support-lobby high-tech-lobby]
  ]
  if member? 5 norms [;"work in agri industry"
    set cash cash + salary
  ]
  if member? 6 norms [;"work in high-tech industry"
    set cash cash + salary
  ]
  if member? 7 norms [;"live in the countryside"
    set cash cash - [cost-of-living] of patch-here
  ]
  if member? 8 norms [;"live in a village"
    set cash cash - [cost-of-living] of patch-here
  ]
  if member? 9 norms [;"live in the city"
    set cash cash - [cost-of-living] of patch-here
  ]
  if member? 10 norms [;"licence required for livestock";
    if licensed-capacity < production-capacity or cash > ((licensed-capacity - production-capacity) / investment-cost) [
      ask public-administration [ license myself [production-capacity - licensed-capacity + max list 0 cash / investment-cost] of myself ]
    ]
  ]
  if member? 11 norms [;"no livestock near populated areas" ; farmers near city and village are bought out
    if member? farmers reference-group-memberships and not [livestock-allowed] of patch-here [be-bought-out]
  ]
  ;if member? 12 norms [;;"freeze production capacity"; the total production capacity in the area is limited; licence requests are rejected if the limit is reached
    ;no specific individual behaviours
  ;]
  ;if member? 13 norms [;"no more licences";                    13                 ; all new licence requests are to be rejected in order to reduce the total production capacity
    ;no specific individual behaviours
  ;]
  if member? 14 norms [;"engage in criminal activities"
    set cash country-cost-of-living
  ]
  if member? 15 norms [;"don't work"
    ifelse member? patients reference-group-memberships [
      set cash cash + max list city-cost-of-living village-cost-of-living
    ][;;else
      if cash <= 0 [set cash min list city-cost-of-living village-cost-of-living]
    ]
  ]
end

to produce-pigs ;; to be performed by an individual farmer ; checked 17-3-2019
  set manure-flow production-capacity * manure-factor
  set bad-air-flow production-capacity * bad-air-factor
  let no-infection 1
  ifelse current-infection-strength > random-float 1 [
    set infection-flow infection-factor
    set no-infection 0
  ][ ;;else
    set infection-flow 0
  ]
  set farm-income (no-infection * current-pig-price - current-production-cost) * production-capacity
  set cash cash + farm-income
end

to invest-in-pig-production-capacity ;; to be performed by an individual farmer ; checked 17-3-2019
  let investment cash - [cost-of-living] of patch-here
  if investment > 0 and member? farmers reference-group-memberships and [livestock-allowed] of patch-here [
    ifelse member? 10 norms [ ;"licence required for livestock"
      if (licensed-capacity > production-capacity) [
        set investment min list investment (investment-cost * (licensed-capacity - production-capacity))
        set production-capacity production-capacity + investment / investment-cost
        set cash cash - investment
      ]
    ][;;else
      set production-capacity production-capacity + investment / investment-cost
      set cash cash - investment
    ]
  ]
end

to support-lobby [a-lobby] ;; to be performed by an individual ; checked 17-3-2019
  if not member? a-lobby lobbies-i-support [ set lobbies-i-support lput a-lobby lobbies-i-support ]
  ask a-lobby [ set support support + [min list village-cost-of-living (production-capacity * ((price-lower-bound + price-upper-bound) / 2 - current-production-cost) + salary)] of myself ]
end

to be-bought-out ;; to be performed by an individual farmer ; checked 17-09-2019
  set cash cash + production-capacity * investment-cost
  let old-licence licensed-capacity
  try-and-leave-reference-group farmers
  if not no-more-licences [set licensed-capacity old-licence]
  adopt-reference-groups-norms
end

to distribute-flows  ; checked 19-09-2019
;; aggregate effects of pig production
  ifelse any? [members] of farmers [
    let new-capacity sum [production-capacity] of [members] of farmers
    set pig-production-growth (new-capacity - annual-pig-production) / annual-pig-production
    set annual-pig-production new-capacity * (1 - current-infection-strength)
    set mean-production-capacity mean [production-capacity] of [members] of farmers
    set annual-manure-production manure-factor * annual-pig-production
  ][;else
    set pig-production-growth 0
    set annual-pig-production 0
    set mean-production-capacity 0
    set annual-manure-production 0
  ]
;; reset local environmental conditions
  ask patches
  [ set air-pollution 0
    set brown-area false
    set patients-here false
    set patients-around false
  ]
  ask patches with [infection-risk > 0 or (pcolor = brown)]
  [ set infection-risk 0
    if land-use = "country" and livestock-allowed [set pcolor green]
    if land-use = "country" and not livestock-allowed [set pcolor lime]
    if land-use = "village" [ set pcolor orange]
    if land-use = "city" [ set pcolor red ]
    if land-use = "centre" [ set pcolor black ]
  ]
;; new local environmental condition
  ask [members] of farmers
  [ ask patch-here
    [ set air-pollution air-pollution + [bad-air-flow] of myself
      if 0 < [infection-flow] of myself [
        set infection-risk [infection-flow] of myself
      ]
    ]
    ask [neighbors] of patch-here
    [ set air-pollution air-pollution + [bad-air-flow] of myself
      if 0 < [infection-flow] of myself [
        set infection-risk [infection-flow] of myself
      ]
    ]
  ]
  ask patches with [air-pollution > bad-air-limit] [
    set pcolor brown
    set brown-area true
    ask neighbors [set brown-area true]
  ]
;; human infections
  ask patches with [infection-risk > 0]
  [ set pcolor pink
    ask individuals-here
    [ if [infection-risk] of patch-here > random-float 1 [
        set infected true
        try-and-join-reference-group patients
      ]
    ]
  ]
  ask [members] of patients
  [ ask patch-here
    [ set patients-here true
      ask neighbors [ set patients-around true ]
    ]
  ]
;; set of countryside patches available on the land market
  set available-farm-estates countryside with [not any? turtles-here]
;; compute relative lobby strength
  set max-lobby-support sum [min list village-cost-of-living (production-capacity * ((price-lower-bound + price-upper-bound) / 2 - current-production-cost) + salary)] of individuals
  ask lobbies
  [ set strength min list 1 (support / max-lobby-support)
    set support 0
  ]
end

to update-uncertainties ; to be performed by an individual
  set uncertainties-pro n-values length-norms-list [basic-uncertainty]
  set uncertainties-contra n-values length-norms-list [basic-uncertainty]
  ifelse member? farmers reference-group-memberships [
    if production-capacity > 0 [
      set uncertainties-pro replace-item 0 uncertainties-pro 1
      set uncertainties-pro replace-item 3 uncertainties-pro 1
      set uncertainties-contra replace-item 1 uncertainties-contra 1
      set uncertainties-contra replace-item 2 uncertainties-contra 1
      set uncertainties-contra replace-item 10 uncertainties-contra 1
      set uncertainties-contra replace-item 11 uncertainties-contra 1
      set uncertainties-contra replace-item 12 uncertainties-contra 1
      set uncertainties-contra replace-item 13 uncertainties-contra 1
      set uncertainties-contra replace-item 14 uncertainties-contra 1
      set uncertainties-contra replace-item 15 uncertainties-contra 1
    ]
  ][;else
    if member? agri-workers reference-group-memberships and salary > 0 [
      set uncertainties-pro replace-item 3 uncertainties-pro 1
      set uncertainties-pro replace-item 5 uncertainties-pro 1
      set uncertainties-pro replace-item 7 uncertainties-pro 1
      set uncertainties-pro replace-item 8 uncertainties-pro 1
      set uncertainties-contra replace-item 13 uncertainties-contra 1
      set uncertainties-contra replace-item 14 uncertainties-contra 1
      set uncertainties-contra replace-item 15 uncertainties-contra 1
    ]
    if member? high-tech-workers reference-group-memberships and salary > 0 [
      set uncertainties-pro replace-item 1 uncertainties-pro 1
      set uncertainties-pro replace-item 4 uncertainties-pro 1
      set uncertainties-pro replace-item 5 uncertainties-pro 1
      set uncertainties-pro replace-item 7 uncertainties-pro 1
      set uncertainties-pro replace-item 9 uncertainties-pro 1
      set uncertainties-pro replace-item 11 uncertainties-pro 1
      set uncertainties-contra replace-item 14 uncertainties-contra 1
      set uncertainties-contra replace-item 15 uncertainties-contra 1
    ]
    if not member? agri-workers reference-group-memberships and pig-production-growth > random-float 1  [
      set uncertainties-pro replace-item 2 uncertainties-pro 1
      set uncertainties-pro replace-item 10 uncertainties-pro 1
      set uncertainties-pro replace-item 12 uncertainties-pro 1
      set uncertainties-pro replace-item 13 uncertainties-pro 1
      set uncertainties-contra replace-item 0 uncertainties-contra 1
      set uncertainties-contra replace-item 3 uncertainties-contra 1
    ]
    if [pcolor = brown] of patch-here or any? neighbors with [pcolor = brown] [
      set uncertainties-pro replace-item 1 uncertainties-pro 1
      set uncertainties-pro replace-item 5 uncertainties-pro 1
      set uncertainties-pro replace-item 11 uncertainties-pro 1
      set uncertainties-contra replace-item 0 uncertainties-contra 1
      set uncertainties-contra replace-item 3 uncertainties-contra 1
      set uncertainties-contra replace-item 7 uncertainties-contra 1
      set uncertainties-contra replace-item 9 uncertainties-contra 1
    ]
    if [patients-here or (land-use = "country" and patients-around)] of patch-here [
      set uncertainties-pro replace-item 1 uncertainties-pro 1
      set uncertainties-pro replace-item 10 uncertainties-pro 1
      set uncertainties-pro replace-item 11 uncertainties-pro 1
      set uncertainties-pro replace-item 12 uncertainties-pro 1
      set uncertainties-pro replace-item 13 uncertainties-pro 1
      set uncertainties-contra replace-item 0 uncertainties-contra 1
      set uncertainties-contra replace-item 3 uncertainties-contra 1
      set uncertainties-contra replace-item 9 uncertainties-contra 1
    ]
    if member? unemployed reference-group-memberships  [
      set uncertainties-pro replace-item 3 uncertainties-pro 1
      set uncertainties-pro replace-item 4 uncertainties-pro 1
      set uncertainties-pro replace-item 5 uncertainties-pro 1
      set uncertainties-pro replace-item 6 uncertainties-pro 1
      set uncertainties-contra replace-item 14 uncertainties-contra 1
    ]
  ]
end

to affect-public-opinion ;; to be performed by a lobby ; checked 27-4-2019
  ask n-of min list 1 int(strength * count individuals) individuals [
    let mu1 1 - stability
    let opinions-1 [ ]
    (foreach opinions uncertainties-pro uncertainties-contra ([opinions] of myself) [ [x z y x2] ->
      ifelse ((x2 - x) <= z) and ((x - x2) <= y) [
        set opinions-1 lput (stability * x + mu1 * x2) opinions-1
      ][;;else
        set opinions-1 lput x opinions-1
      ]
    ])
    set opinions opinions-1
  ]
end

to exchange-opinions-in-reference-group ;; opinion dynamics to be performed by a reference group
  let n-partners max list 0 min list interaction-partners (count members - 1)
  ask members
  [ let mu1 1 - stability
    let partners sort n-of n-partners other ([members] of myself)
;    let partners sort n-of n-partners ([members] of myself)
;    while [member? self partners] [ set partners sort n-of n-partners ([members] of myself) ]
    foreach partners [ partner ->
      let s2 [stability] of partner
      let mu2 1 - s2
      let opinions-1 [ ]
      let opinions-2 [ ]
      (foreach opinions uncertainties-pro uncertainties-contra ([opinions] of partner) ([uncertainties-pro] of partner) ([uncertainties-pro] of partner) [ [x1 z1 y1 x2 z2 y2] ->
        ifelse ((x2 - x1) <= z1) and ((x1 - x2) <= y1) [
          set opinions-1 lput (stability * x1 + mu1 * x2) opinions-1
        ][;;else
          set opinions-1 lput x1 opinions-1
        ]
        ifelse ((x1 - x2) < z2) and ((x2 - x1) < y2) [
          set opinions-2 lput (stability * x2 + mu1 * x1) opinions-2
        ][;;else
          set opinions-2 lput x2 opinions-2
        ]
      ])
      set opinions opinions-1
      ask partner [set opinions [opinions-2] of myself]
    ]
  ]
end

to reconsider-norms ;; to be performed by a reference group
; not operational in present version; could be something like:
;  if any? members [
;    let sum-opinions n-values length-norms-list [0]
;    let plus-member-s-opinions [ ]
;    foreach sort members [member ->
;      set plus-member-s-opinions [ ]
;      (foreach sum-opinions [opinions] of member [ [sum-opinion member-s-opinion] ->
;        set plus-member-s-opinions lput (sum-opinion + member-s-opinion) plus-member-s-opinions
;      ])
;      set sum-opinions plus-member-s-opinions
;    ]
;    set opinions [ ]
;    let new-norms [ ]
;    let norm-index 0
;    let count-members count members
;    foreach sum-opinions [ sum-opinion ->
;      let members-opinion sum-opinion / count-members
;      set opinions lput members-opinion opinions
;      ifelse members-opinion < (1 - norm-adoption-threshold) and member? norm-index norms [
;        set norms remove norm-index norms
;      ]
;      [; else
;        if members-opinion > norm-adoption-threshold and not member? norm-index norms [
;          set norms lput norm-index norms
;        ]
;      ]
;      set norm-index norm-index + 1
;    ]
;  ]
end

to reconsider-group-memberships ;; to be performed by an individual to decide on reference group memberships ; checked 19-8-2018
;; bought-out farmers search for a new farm
  if member? 0 norms and not member? farmers reference-group-memberships [try-and-join-reference-group farmers]
;; rich high-tech or agri workers can buy a place to live in the countryside
  if [land-use != "country"] of patch-here
      and (cash > farm-estate-value)
      and (salary > country-cost-of-living)
      and any? available-farm-estates with [not brown-area] [
    move-to one-of available-farm-estates with [not brown-area]
    ask patch-here [set available-farm-estates other available-farm-estates]
    set cash cash - farm-estate-value
    try-and-join-reference-group commuters
  ]
;; country dwellers in financial trouble sell to municipalities, engage in crime, or migrate to village areas
  if ["country" = land-use] of patch-here and cash < (- 2 * production-capacity * ((price-lower-bound + price-upper-bound) / 2 - current-production-cost)) [
    ifelse any? neighbors4 with [land-use = "city"] [
      ask patch-here [ set-patch-city ]
      try-and-join-reference-group urbanites
    ][ ;;else
      ifelse any? neighbors4 with [land-use = "village"] [
        ask patch-here [ set-patch-village ]
        try-and-join-reference-group villagers
      ][ ;;else
        ifelse crim-susceptible [
          try-and-join-reference-group countryside-criminals
        ][;;else
          try-and-join-reference-group villagers
        ]
      ]
    ]
  ]
;; other individuals in financial trouble can try and find a cheaper place to live
  if ["city" = land-use] of patch-here and cash < 0 and (village-cost-of-living < city-cost-of-living) [try-and-join-reference-group villagers]
  if ["village" = land-use] of patch-here and cash < 0 and (city-cost-of-living < village-cost-of-living) [try-and-join-reference-group urbanites]
;; bad environmental conditions lead to support for responsibility lobbies and migration from the countryside
  if not member? farmers reference-group-memberships [
    if not member? agri-workers reference-group-memberships [
      if pig-production-growth > random-float 1 [try-and-join-reference-group globally-involved]
      if [brown-area] of patch-here [try-and-join-reference-group locally-involved]
    ]
    if [patients-here or (land-use = "country" and patients-around)] of patch-here [try-and-join-reference-group locally-involved]
    if ["country" = land-use and (brown-area or patients-around)] of patch-here [
      try-and-join-reference-group urbanites
    ]
  ]
end

to a-preliminary-idea-for-opinion-and-condition-based-change-of-memberships
  foreach sort reference-groups [ ref-group ->
    if ref-group != public-administration     ;; every individual in the region is always a member of public-administration
    and (ref-group != unemployed) [           ;; reference group "unemployed" can only be joined or left through the labor market or quitting or starting a farm
      let n-norms [length norms] of ref-group
      if n-norms > 0 [
        let sum-opinions 0                    ;; an individual's opinion about a group depends on its op[nions about the group's norms
        foreach [norms] of ref-group [ref-group-norm ->
          set sum-opinions sum-opinions + item ref-group-norm opinions
        ]
        let my-average-opinion-on-ref-group-s-norms sum-opinions / n-norms
        ifelse member? ref-group reference-group-memberships [
          if my-average-opinion-on-ref-group-s-norms < (1 - norm-adoption-threshold)      ;; an individual wants to leave if its opinions about the norms are bad
          or not check-membership-conditions-for ref-group [          ;; or if the group's membership conditions can no longer be met
            try-and-leave-reference-group ref-group
          ]
        ][;;else                                                      ;; an individual wants to join groups it has good opinions about
          if my-average-opinion-on-ref-group-s-norms > norm-adoption-threshold [
            try-and-join-reference-group ref-group
          ]
        ]
      ]
    ]
  ]
end

to try-and-join-reference-group [a-reference-group] ;; to be performed by an individual ;to be checked
  if not (member? a-reference-group reference-group-memberships) [
    ifelse a-reference-group = farmers [
    ; condition 1: sufficient capital
      if ((cash > (farm-estate-value + mean-production-capacity * investment-cost))
        or (["country" = land-use] of patch-here and cash > mean-production-capacity * investment-cost))
    ; condition 2: location available
      and ([livestock-allowed] of patch-here or any? available-farm-estates with [livestock-allowed])
    ; condition 3: livestock production licence available or not required
      and ((not licence-required-for-livestock) or (licensed-capacity > 0) or (licence-required-for-livestock and licence-available))
    ; condition 4: patients cannot work
      and not member? patients reference-group-memberships [
    ; then:
        if [not livestock-allowed] of patch-here [ ;; move to a location where livestock keeping is allowed
          if ["country" != land-use] of patch-here [set cash cash - farm-estate-value]
          move-to one-of available-farm-estates with [livestock-allowed]
          ask patch-here [ set available-farm-estates other available-farm-estates ]
        ]
        add-reference-group-membership farmers
        if not member? countryside-criminals reference-group-memberships [set color blue]
        try-and-leave-reference-group urbanites
        try-and-leave-reference-group villagers
        try-and-leave-reference-group commuters
        try-and-leave-reference-group agri-workers
        try-and-leave-reference-group high-tech-workers
        try-and-leave-reference-group unemployed
        set quitted-farming false
        invest-in-pig-production-capacity
      ]
    ][ ;; end farmers
      ifelse a-reference-group = agri-workers [
      ; condition: can only be joined through the labor market
        if labor-market-running [
          add-reference-group-membership agri-workers
          if not member? countryside-criminals reference-group-memberships [set color white]
          try-and-leave-reference-group high-tech-workers
          try-and-leave-reference-group farmers
          try-and-leave-reference-group unemployed
          if ["country" = land-use] of patch-here [try-and-join-reference-group commuters]
          set salary village-cost-of-living + random-float (2 * (mean-salary-agri - village-cost-of-living))
        ]
      ][ ;; end agri-workers
        ifelse a-reference-group = high-tech-workers [
        ; condition: can only be joined through the labor market
          if labor-market-running [
            add-reference-group-membership high-tech-workers
            if not member? countryside-criminals reference-group-memberships [set color grey]
            try-and-leave-reference-group agri-workers
            try-and-leave-reference-group farmers
            try-and-leave-reference-group unemployed
            if ["country" = land-use] of patch-here [try-and-join-reference-group commuters]
            set salary city-cost-of-living + random-float (2 * (mean-salary-tech - city-cost-of-living))
          ]
        ][ ;; end high-tech-workers
          ifelse a-reference-group = unemployed [
          ; condition: can only be joined through the labor market or if just quitted farming and not infected
            if (labor-market-running or quitted-farming) and not infected [
              set quitted-farming false
              add-reference-group-membership unemployed
              if not member? countryside-criminals reference-group-memberships [set color black]
              try-and-leave-reference-group agri-workers
              try-and-leave-reference-group high-tech-workers
            ]
          ][ ;; end unemployed
            ifelse a-reference-group = patients [
            ; condition: can only be joined if infected
              if infected [
                add-reference-group-membership patients
                if not member? countryside-criminals reference-group-memberships [set color yellow]
                try-and-leave-reference-group farmers
                try-and-leave-reference-group high-tech-workers
                try-and-leave-reference-group agri-workers
                try-and-leave-reference-group unemployed
              ]
            ][ ;; end patients
              ifelse a-reference-group = urbanites [
              ; condition: must be on a city patch or space must be avalable in the city (if not, city is expanded)
                if ["city" != land-use] of patch-here [
                  if ["country" = land-use] of patch-here [set cash cash + farm-estate-value]
                  if not any? city with [count turtles-here < 25] [ ask public-administration [expand-city] ]
                  move-to one-of city with [count turtles-here < 25]
                ]
                add-reference-group-membership urbanites
                try-and-leave-reference-group farmers
                try-and-leave-reference-group countryside-criminals
                try-and-leave-reference-group commuters
                try-and-leave-reference-group villagers
              ][ ;; end urbanites
                ifelse a-reference-group = villagers [
                ; condition: must be on a village patch or space must be avalable in the village (if not, village is expanded)
                  if ["village" != land-use] of patch-here [
                    if ["country" = land-use] of patch-here [set cash cash + farm-estate-value]
                    if not any? village with [count turtles-here < 10] [ ask public-administration [expand-village] ]
                    move-to one-of village with [count turtles-here < 10]
                  ]
                  add-reference-group-membership villagers
                  try-and-leave-reference-group farmers
                  try-and-leave-reference-group countryside-criminals
                  try-and-leave-reference-group commuters
                  try-and-leave-reference-group urbanites
                ][ ;; end villagers
                  ifelse a-reference-group = commuters [
                  ; condition: must be on a countryside patch
                    if ["country" = land-use] of patch-here [
                      add-reference-group-membership commuters
                      try-and-leave-reference-group villagers
                      try-and-leave-reference-group urbanites
                    ]
                  ][ ;; end commuters
                    ifelse a-reference-group = countryside-criminals [
                    ; condition: must be in financial trouble and dwelling on a countryside patch
                      if cash < 0 and (["country" = land-use] of patch-here) [
                        add-reference-group-membership countryside-criminals
                        set cash 0
                        set color red
                      ]
                    ][ ;; end countryside-criminals
                      add-reference-group-membership a-reference-group
  ] ] ] ] ] ] ] ] ]
    adopt-reference-groups-norms
  ]
end

to add-reference-group-membership [a-reference-group] ;; to be performed by an individual, to add a reference group membership ; checked 17-3-2019
  set reference-group-memberships lput a-reference-group reference-group-memberships
  foreach [norms] of a-reference-group [pro-norm -> set opinions replace-item pro-norm opinions 1]
  ask a-reference-group [set members (turtle-set members myself)]
end

to try-and-leave-reference-group [a-reference-group] ;; to be performed by an individual to quit reference-group membership; to be checked
  if member? a-reference-group reference-group-memberships
  and a-reference-group != public-administration              ;; individuals must remain members of public-administration
  and a-reference-group != patients                           ;; patients remain patients
  [
    ifelse a-reference-group = farmers [
      ;quit farming:
      set production-capacity 0
      set licensed-capacity 0
      set manure-flow 0
      set bad-air-flow 0
      set infection-flow 0
      set quitted-farming true
      remove-reference-group-membership farmers
      try-and-join-reference-group unemployed
    ][ ;; end farmers
      ifelse a-reference-group = agri-workers [
        if member? farmers reference-group-memberships
        or member? high-tech-workers reference-group-memberships
        or member? unemployed reference-group-memberships
        or member? patients reference-group-memberships [
          set salary 0
          remove-reference-group-membership agri-workers
        ]
      ][ ;; end agri-workers
        ifelse a-reference-group = high-tech-workers [
          if member? farmers reference-group-memberships
          or member? agri-workers reference-group-memberships
          or member? unemployed reference-group-memberships
          or member? patients reference-group-memberships [
            set salary 0
            remove-reference-group-membership high-tech-workers
          ]
        ][ ;; end high-tech-workers
          ifelse a-reference-group = unemployed [
            if member? farmers reference-group-memberships
            or member? agri-workers reference-group-memberships
            or member? high-tech-workers reference-group-memberships
            or member? patients reference-group-memberships [
              remove-reference-group-membership unemployed
            ]
          ][ ;; end unemployed
            ifelse a-reference-group = patients [
            ; condition: can only be left if cured
              if not infected [
                remove-reference-group-membership patients
                add-reference-group-membership unemployed
                if not member? countryside-criminals reference-group-memberships [set color black]
              ]
            ][ ;; end patients
              ifelse a-reference-group = urbanites [
              if member? farmers reference-group-memberships
              or member? commuters reference-group-memberships
              or member? villagers reference-group-memberships [
                remove-reference-group-membership urbanites
              ]
              ][ ;; end urbanites
                ifelse a-reference-group = villagers [
                  if member? farmers reference-group-memberships
                  or member? commuters reference-group-memberships
                  or member? urbanites reference-group-memberships [
                    remove-reference-group-membership villagers
                  ]
                ][ ;; end villagers
                  ifelse a-reference-group = commuters [
                    if member? farmers reference-group-memberships
                    or member? villagers reference-group-memberships
                    or member? urbanites reference-group-memberships [
                      remove-reference-group-membership commuters
                    ]
                  ][ ;; end commuters
                    ifelse a-reference-group = countryside-criminals [
                      if ["country" != land-use] of patch-here [
                        remove-reference-group-membership countryside-criminals
                        ifelse member? patients reference-group-memberships [
                          set color yellow
                        ][;;else
                          ifelse member? agri-workers reference-group-memberships [
                            set color blue
                          ][;;else
                            ifelse member? high-tech-workers reference-group-memberships [
                              set color white
                            ][;;else (unemployed)
                              set color black
                        ] ] ]
                      ]
                    ][ ;; end countryside-criminals
                      remove-reference-group-membership a-reference-group
    ] ] ] ] ] ] ] ] ]
    adopt-reference-groups-norms
  ]
end

to remove-reference-group-membership [a-reference-group] ;; to be performed by an individual, to remove a reference group membership ; checked 17-3-2019
    set reference-group-memberships remove a-reference-group reference-group-memberships
    let other-members-of-a-reference-group other [members] of a-reference-group
    ask a-reference-group [set members [other-members-of-a-reference-group] of myself]
end

to-report check-membership-conditions-for [a-reference-group] ; checked 17-3-2019
  ifelse a-reference-group = farmers [
  ; condition 1: sufficient capital
    report (cash > ( - production-capacity * investment-cost))
  ; condition 2: location available
    and ([livestock-allowed] of patch-here)
  ; condition 3: livestock production licence not required or available
    and ((not member? 10 norms) or (licensed-capacity > 0))
  ; condition 4: patients cannot work
    and not member? patients reference-group-memberships
  ][ ;; end farmers
    report true
  ]
end

to adopt-reference-groups-norms ;; to be performed by an individual to set norms according to current reference group memberships ; checked 13-8-2018
  set norms [ ]
  foreach reference-group-memberships [ref-group ->
    foreach [norms] of ref-group [ref-group-norm ->
      if not member? ref-group-norm norms [set norms lput ref-group-norm norms]
    ]
  ]
end

to affect-political-parties ;; to be performed by a lobby ; checked 17-3-2019
  ask political-parties [
    let influence lobby-effectiveness * ([strength] of myself) * (1 - (abs (local-orientation - [local-orientation] of myself)
      + abs (social-responsibility-orientation - [social-responsibility-orientation] of myself)) / 2)
    let updated-opinions [ ]
    ( foreach opinions [opinions] of myself [ [party-op lobby-op] ->
      ifelse lobby-op = 0.5 [
        set updated-opinions lput party-op updated-opinions
      ][;;else
        set updated-opinions lput ((1 - influence) * party-op + influence * lobby-op) updated-opinions
      ]
    ]  )
    set opinions updated-opinions
  ]
end

to vote  ;; to be performed by an individual ; checked 17-3-2019
  set my-party no-turtles
  set my-party-distance length-norms-list
  foreach sort political-parties
  [ this-party ->
    let this-party-distance 0
    (foreach opinions ([opinions] of this-party) [ [my-opinion party-opinion] -> set this-party-distance this-party-distance + abs (my-opinion - party-opinion) ])
    ifelse this-party-distance < my-party-distance [
      set my-party turtle-set this-party
      set my-party-distance this-party-distance
    ][;;else
        if this-party-distance = my-party-distance [set my-party (turtle-set my-party this-party)]
    ]
  ]
  set my-party one-of my-party
  ask my-party [ set votes votes + 1 ]
end

to run-labor-market ;; general procedure to run the labor market for agri and high tech industries ; checked 18-09-2019
  set labor-market-running true
  set current-agri-workers count [members] of agri-workers
  set agri-employment int ((sum [production-capacity] of [members] of farmers) * agri-complex-employment / 1000)
  set current-tech-workers count [members] of high-tech-workers
  set tech-employment int (current-tech-workers * (100 + ((random-float 3) - 0.5) * tech-industry-growth) / 100)
;;lay-offs:
  if current-agri-workers > agri-employment [
    ask n-of (current-agri-workers - agri-employment) [members] of agri-workers
    [ try-and-join-reference-group unemployed
      adopt-reference-groups-norms
    ]
    set current-agri-workers agri-employment
  ]
  if current-tech-workers > tech-employment [
    ask n-of (current-tech-workers - tech-employment) [members] of high-tech-workers
    [ try-and-join-reference-group unemployed
      adopt-reference-groups-norms
    ]
    set current-tech-workers tech-employment
  ]
  set number-of-unemployed [count members] of unemployed
;;recruit unemployed for agri-industry
  let to-be-recruited min list number-of-unemployed (agri-employment - current-agri-workers)
  if to-be-recruited > 0 [
    ask n-of to-be-recruited [members] of unemployed
    [ try-and-join-reference-group agri-workers
      adopt-reference-groups-norms
    ]
    set current-agri-workers current-agri-workers + to-be-recruited
    set number-of-unemployed number-of-unemployed - to-be-recruited
  ]
;;employ unemployed in high-tech industry
  set to-be-recruited min list number-of-unemployed (tech-employment - current-tech-workers)
  if to-be-recruited > 0 [
    ask n-of to-be-recruited [members] of unemployed
    [ try-and-join-reference-group high-tech-workers
      adopt-reference-groups-norms
    ]
    set current-tech-workers current-tech-workers + to-be-recruited
    set number-of-unemployed number-of-unemployed - to-be-recruited
  ]
  set labor-market-running false
end ;; run-labor-market

to emigration-and-immigration ; checked 18-09-2019
;;some remaining unemployed emigrate to find work
  ask [members] of unemployed [ if emigration-factor > random-float 1 [emigrate] ]
  set number-of-unemployed [count members] of unemployed
;; high-tech employees living on the edge of the city emigrate in case of bad environmental conditions
  set emigrated-high-tech-employees 0
  ask city with [any? neighbors with [(land-use = "country") and (pcolor = brown)]]
  [ ask individuals-here
    [ if member? high-tech-workers reference-group-memberships [
      set emigrated-high-tech-employees emigrated-high-tech-employees + 1
      emigrate
      ]
    ]
  ]
  set labor-market-running true
;;recruit immigrants for agri-industry
  let to-be-recruited agri-employment - current-agri-workers
  if to-be-recruited > 0 [
    ask centre
    [ sprout-individuals to-be-recruited
      [ initialise-individual
        set actor-type "immigrant"
        try-and-join-reference-group villagers
        try-and-join-reference-group agri-workers
        adopt-reference-groups-norms
        set-initial-opinions
      ]
    ]
    set current-agri-workers agri-employment
  ]
;;recruit immigrants for high-tech industry
  set to-be-recruited tech-employment - current-tech-workers
  if to-be-recruited > 0 [
    ask centre
    [ sprout-individuals to-be-recruited
      [ initialise-individual
        set actor-type "immigrant"
        try-and-join-reference-group urbanites
        try-and-join-reference-group high-tech-workers
        adopt-reference-groups-norms
        set-initial-opinions
      ]
    ]
    set current-tech-workers tech-employment
  ]
  set labor-market-running false
end ; emigration-and-immigration

to emigrate ; to be performed by an individual ; checked 17-3-2019
  foreach reference-group-memberships [ m -> remove-reference-group-membership m ]
  die
end

to expand-village ;;general procedure to expand village by expropriating country land owners ; checked 17-3-2019
  ask one-of village with [any? neighbors4 with [land-use = "country"]]
  [ ask one-of neighbors4 with [land-use = "country"]
    [ set-patch-village
      ask turtles-here ;; land owners are expropriated
      [ set cash cash + farm-estate-value + production-capacity * investment-cost
        let old-licence licensed-capacity
        try-and-join-reference-group villagers
        if not no-more-licences [set licensed-capacity old-licence]
        adopt-reference-groups-norms
      ]
      if member? self available-farm-estates [
        set available-farm-estates other available-farm-estates
      ]
    ]
  ]
end

to expand-city ;;general procedure to expand city by expropriating country land owners ; checked 17-3-2019
  ask one-of city with [any? neighbors4 with [land-use = "country"]]
  [ ask one-of neighbors4 with [land-use = "country"]
    [ set-patch-city
      ask turtles-here ;; land owners are expropriated
      [ set cash cash + farm-estate-value + production-capacity * investment-cost
        let old-licence licensed-capacity
        try-and-join-reference-group urbanites
        if not no-more-licences [set licensed-capacity old-licence]
        adopt-reference-groups-norms
      ]
      if member? self available-farm-estates [
        set available-farm-estates other available-farm-estates
      ]
    ]
  ]
end

to make-policy ;; to be performed by public administration; ; checked 21-3-2019
  let sum-votes sum [votes] of political-parties
  let weighted-opinions n-values length-norms-list [0]
  foreach sort political-parties [ a-party ->
    let weight [votes] of a-party / sum-votes
    let adm-opinions [ ]
    (foreach weighted-opinions [opinions] of a-party
    [ [weighted-opinion party-opinion] ->
      set adm-opinions lput (weight * party-opinion + weighted-opinion) adm-opinions
    ])
    set weighted-opinions adm-opinions
  ]
  if auto-politics [
; "licence required for livestock";      10                  ; farmers must have a licence to produce pigs
    if not licence-required-for-livestock and item 10 weighted-opinions > policy-threshold [ set licence-required-for-livestock true ]
;    if licence-required-for-livestock and item 10 weighted-opinions < (1 - policy-threshold) [ set licence-required-for-livestock false ]
; "no livestock near populated areas";   11                 ; farmers near city and village are bought out and no licences are granted near city and village
    if not not-near-the-city and item 11 weighted-opinions > policy-threshold [ set not-near-the-city true ]
;    if not-near-the-city and item 11 weighted-opinions < (1 - policy-threshold) [ set not-near-the-city false ]
; "freeze production capacity";          12                 : the total production capacity in the area is limited; licence requests are rejected if the limit is reached
    if not freeze-production-capacity and item 12 weighted-opinions > policy-threshold [ set freeze-production-capacity true ]
;    if freeze-production-capacity and item 12 weighted-opinions < (1 - policy-threshold) [ set freeze-production-capacity false ]
; "no more licences";                    13                 ; all new licence requests are to be rejected in order to reduce the total production capacity
    if not no-more-licences and item 13 weighted-opinions > policy-threshold [ set no-more-licences true ]
;    if no-more-licences and item 13 weighted-opinions < (1 - policy-threshold) [ set no-more-licences false ]
  ]
  if freeze-production-capacity or no-more-licences or not-near-the-city [set licence-required-for-livestock true]
  let communicate-new-public-norms false
  if licence-required-for-livestock and not member? 10 norms [
    set norms lput 10 norms
    set communicate-new-public-norms true
  ]
;  if not licence-required-for-livestock and member? 10 norms [
;    set norms remove 10 norms
;    set communicate-new-public-norms true
;  ]
  if not-near-the-city and not member? 11 norms [
    set norms lput 11 norms
    set communicate-new-public-norms true
  ]
;  if not not-near-the-city and member? 11 norms [
;    set norms remove 11 norms
;    set communicate-new-public-norms true
;  ]
  if freeze-production-capacity and not member? 12 norms [
    set norms lput 12 norms
    set communicate-new-public-norms true
  ]
;  if not freeze-production-capacity and member? 12 norms [
;    set norms remove 12 norms
;    set communicate-new-public-norms true
;  ]
  if no-more-licences and not member? 13 norms [
    set norms lput 13 norms
    set communicate-new-public-norms true
  ]
;  if not no-more-licences and member? 13 norms [
;    set norms remove 13 norms
;    set communicate-new-public-norms true
;  ]
  if communicate-new-public-norms [ ask members [ adopt-reference-groups-norms ] ]
end

to apply-policy ;; to be performed by public administration ; checked 17-3-2019
  ifelse member? 11 norms [ ; "no livestock near populated areas"
    ask countryside with [any? neighbors with [land-use = "city" or land-use = "village"]]
    [ set livestock-allowed false
      if pcolor != brown [set pcolor lime]
      ask neighbors
      [ set livestock-allowed false
        if land-use = "country" [if pcolor != brown [set pcolor lime]]
;        ask neighbors
;        [ set livestock-allowed false
;          if land-use = "country" [if pcolor != brown [set pcolor lime]]
;        ]
      ]
    ]
  ][;;else
    ask countryside with [not livestock-allowed]
    [ set livestock-allowed true
      if pcolor != brown [set pcolor green]
    ]
  ]
  ifelse member? 13 norms [ ; "no more licences"
    set frozen-licensed-capacity 0
    set licence-available false
  ][ ;else
    ifelse freeze-production-capacity [
      ifelse frozen-licensed-capacity = 0 [
        ask [members with [licensed-capacity < production-capacity]] of farmers [ set licensed-capacity production-capacity ]
        let sum-production-capacity [sum [production-capacity] of members] of farmers
        set frozen-licensed-capacity sum-production-capacity
        set total-licensed-capacity sum-production-capacity
      ][;else
        set total-licensed-capacity [sum [licensed-capacity] of members] of farmers
      ]
      set licence-available frozen-licensed-capacity > total-licensed-capacity
    ][;;else
      set frozen-licensed-capacity 0
      set licence-available true
    ]
  ]
end

to license [a-farmer requested-capacity] ;; to be performed by public administration ; checked 17-3-2019
  if licence-available and ([[livestock-allowed] of patch-here] of a-farmer) [
    ifelse not freeze-production-capacity [
      ask a-farmer [ set licensed-capacity licensed-capacity + requested-capacity ]
    ][ ;;else
      if licence-available [
        ask a-farmer [ set licensed-capacity licensed-capacity + min list requested-capacity (frozen-licensed-capacity - total-licensed-capacity) ]
        set total-licensed-capacity min list frozen-licensed-capacity (total-licensed-capacity + requested-capacity)
        set licence-available frozen-licensed-capacity > total-licensed-capacity
      ]
    ]
  ]
end

to set-patch-city ;; to be performed by a patch to give it city properties ; checked 17-3-2019
  if land-use = "village" [set village other village]
  if land-use = "country" [set countryside other countryside]
  if not member? self city [set city (patch-set city self)]
  set land-use "city"
  set pcolor red
  set livestock-allowed false
  set patients-around false
  set brown-area false
  set cost-of-living city-cost-of-living
end

to set-patch-village ;; to be performed by a patch to give it village properties ; checked 17-3-2019
  if land-use = "city" [set city other city]
  if land-use = "country" [set countryside other countryside]
  if not member? self village [set village (patch-set village self)]
  set land-use "village"
  set pcolor orange
  set livestock-allowed false
  set patients-around false
  set brown-area false
  set cost-of-living village-cost-of-living
end

to set-patch-country ;; to be performed by a patch to give it countryside properties ; checked 17-3-2019
  if land-use = "city" [set city other city]
  if land-use = "village" [set village other village]
  if not member? self countryside [set countryside (patch-set countryside self)]
  set land-use "country"
  set pcolor green
  set livestock-allowed true
  set patients-around false
  set brown-area false
  set cost-of-living country-cost-of-living
end

to initialise-individual ; checked 17-3-2019
  set shape "person"
  set size 0.8
  set cash 0
  set stability (1 - opinion-dynamics-mu)
  set my-party nobody
  set norms [ ]
  set lobbies-i-support [ ]
  ask public-administration [ set members (turtle-set members myself) ]
  set reference-group-memberships (list public-administration)
  set opinions n-values length-norms-list [0.5]
  set basic-uncertainty initial-uncertainty-min + random-float (initial-uncertainty-max - initial-uncertainty-min)
  set uncertainties-pro n-values length-norms-list [basic-uncertainty]
  set uncertainties-contra n-values length-norms-list [basic-uncertainty]
  set quitted-farming false
  set infected false
  set crim-susceptible criminal-susceptibility > random-float 1
  set support-high-tech false
end

to set-initial-opinions ;; to be performed by a newly sprouted individual after adopt-reference-groups-norms ; checked 17-3-2019
  foreach norms [pro-norm -> set opinions replace-item pro-norm opinions 1]
end

to compute-statistics
  let sum-opinions n-values length-norms-list [0]
  ask individuals
  [ let new-sum-opinions [ ]
    (foreach opinions sum-opinions [ [my-opinion sum-opinion] -> set new-sum-opinions lput (my-opinion + sum-opinion) new-sum-opinions ])
    set sum-opinions new-sum-opinions
  ]
  let new-public-opinion [ ]
  let count-individuals count individuals
  foreach sum-opinions [ sum-opinion -> set new-public-opinion lput (sum-opinion / count-individuals) new-public-opinion]
  set public-opinion new-public-opinion
  set farms count [members] of farmers
  set annual_production annual-pig-production
  ifelse any? [members] of farmers [set farm_income mean [farm-income] of [members] of farmers] [set farm_income 0]
  set agri_employment agri-employment
  set tech_employment tech-employment
  set total_tech_emigration total_tech_emigration + emigrated-high-tech-employees
end
@#$#@#$#@
GRAPHICS-WINDOW
9
10
644
646
-1
-1
19.0
1
10
1
1
1
0
1
1
1
-16
16
-16
16
1
1
1
ticks
30.0

BUTTON
850
10
913
43
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
915
10
978
43
step1
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
980
10
1044
43
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
1459
344
1656
377
mean-salary-agri
mean-salary-agri
village-cost-of-living
200000
40000.0
1000
1
euro/year
HORIZONTAL

SLIDER
1459
377
1656
410
agri-complex-employment
agri-complex-employment
0
5
1.0
0.10
1
/kpigs
HORIZONTAL

SLIDER
1459
519
1656
552
country-cost-of-living
country-cost-of-living
0
100000
30000.0
1000
1
euro/year
HORIZONTAL

SLIDER
1459
552
1656
585
city-cost-of-living
city-cost-of-living
0
100000
25000.0
1000
1
euro/year
HORIZONTAL

SLIDER
1458
464
1655
497
tech-industry-growth
tech-industry-growth
- 5
5
3.3
0.1
1
%/year
HORIZONTAL

SLIDER
1458
431
1655
464
mean-salary-tech
mean-salary-tech
city-cost-of-living
200000
50000.0
1000
1
euro/year
HORIZONTAL

SLIDER
1459
263
1656
296
outbreak-frequency
outbreak-frequency
0
1
0.04
0.005
1
/year
HORIZONTAL

SLIDER
1459
164
1656
197
initial-input-cost
initial-input-cost
0
200
70.0
1
1
euro/pig
HORIZONTAL

PLOT
1247
196
1447
346
farm capacity distribution
animals/year
farms
0.0
100000.0
0.0
1000.0
false
false
"set-plot-x-range 0 100000\nset-plot-y-range 0 1000\nset-histogram-num-bars 40" ""
PENS
"default" 1.0 1 -16777216 false "" "histogram [production-capacity] of [members] of farmers"

PLOT
847
496
1108
646
relative lobby strength
years
NIL
0.0
50.0
0.0
1.0
true
true
"" ""
PENS
"livestock" 1.0 0 -16777216 true "" "plot [strength] of livestock-lobby"
"high-tech" 1.0 0 -7500403 true "" "plot [strength] of high-tech-lobby"
"global resp." 1.0 0 -10899396 true "" "plot [strength] of global-responsibility-lobby"
"local resp." 1.0 0 -2674135 true "" "plot [strength] of local-responsibility-lobby"

PLOT
647
196
847
346
farms
years
N
0.0
50.0
0.0
1000.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot [count members] of farmers"

PLOT
647
346
847
496
unemployed
years
N
0.0
50.0
0.0
1000.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot count [members] of unemployed"

PLOT
847
196
1047
346
total annual pig production
years
k animals/year
0.0
50.0
0.0
2000.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot (1 - current-infection-strength) * annual-pig-production / 1000"

SLIDER
1459
98
1656
131
price-upper-bound
price-upper-bound
0
200
130.0
1
1
euro/pig
HORIZONTAL

SLIDER
1459
131
1656
164
price-lower-bound
price-lower-bound
0
200
110.0
1
1
euro/pig
HORIZONTAL

SLIDER
1682
27
1855
60
opinion-dynamics-mu
opinion-dynamics-mu
0
.5
0.2
.01
1
NIL
HORIZONTAL

PLOT
1047
196
1247
346
mean farm income
years
keuro
0.0
50.0
0.0
100.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot mean-production-capacity * (current-pig-price - current-production-cost) / 1000\n"

TEXTBOX
1460
49
1610
67
LIVESTOCK FARMING
11
0.0
1

TEXTBOX
1460
329
1610
347
AGRI INDUSTRY
11
0.0
1

TEXTBOX
1461
414
1611
432
HIGH TECH INDUSTRY
11
0.0
1

TEXTBOX
1462
502
1612
520
COST OF LIVING
11
0.0
1

SLIDER
1049
10
1245
43
simulation-time
simulation-time
0
100
50.0
5
1
years
HORIZONTAL

SLIDER
1459
585
1656
618
village-cost-of-living
village-cost-of-living
0
100000
20000.0
1000
1
euro/year
HORIZONTAL

SLIDER
1459
230
1656
263
investment-cost
investment-cost
0
1000
200.0
10
1
euro/pig/year
HORIZONTAL

SLIDER
1459
617
1656
650
farm-estate-value
farm-estate-value
0
2000000
1000000.0
100000
1
euro
HORIZONTAL

SLIDER
1459
65
1656
98
mean-initial-capacity
mean-initial-capacity
0
2000
500.0
10
1
pigs/year
HORIZONTAL

BUTTON
1459
10
1658
43
reset default values
DEFAULT
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
847
346
1108
496
employment / 1000
years
NIL
0.0
50.0
0.0
10.0
true
true
"" ""
PENS
"agri complex" 1.0 0 -16777216 true "" "plot count [members] of agri-workers / 1000"
"high-tech" 1.0 0 -7500403 true "" "plot count [members] of high-tech-workers / 1000"

SLIDER
1459
197
1656
230
external-policy-effect
external-policy-effect
0
0.1
0.042
0.001
1
NIL
HORIZONTAL

TEXTBOX
1687
10
1837
28
OPINION DYNAMICS
11
0.0
1

TEXTBOX
649
10
844
196
PATCH COLOR LEGEND:\n  Red: City               Black: Centre\n  Orange: Village\n  Green: Country     \n  Lime: Country, no livestock allowed\n  Brown: Bad air \n  Pink: Infection\nPERSON COLOR LEGEND:\n  Blue: Farmer         Red: Farmer in crime\n  White: Agri-industry worker\n  Grey: High-tech worker\n  Black: Unemployed\n  Yellow: Patient
11
0.0
1

PLOT
647
496
847
646
high-tech staff emigration
years
employees
0.0
50.0
0.0
100.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot emigrated-high-tech-employees"

SWITCH
1250
50
1447
83
licence-required-for-livestock
licence-required-for-livestock
0
1
-1000

SWITCH
1251
85
1446
118
freeze-production-capacity
freeze-production-capacity
0
1
-1000

SWITCH
1250
120
1446
153
no-more-licences
no-more-licences
0
1
-1000

SWITCH
1250
155
1446
188
not-near-the-city
not-near-the-city
0
1
-1000

SWITCH
1250
10
1447
43
auto-politics
auto-politics
0
1
-1000

PLOT
1047
46
1247
196
regional economy
years
index
0.0
50.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot sum [(salary + production-capacity * current-pig-price)] of individuals / index-base"

PLOT
847
46
1047
196
population (households)
years
total / 1000
0.0
50.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot count individuals / 1000"

SLIDER
1682
59
1854
92
initial-uncertainty-min
initial-uncertainty-min
0
1
0.4
.01
1
NIL
HORIZONTAL

SLIDER
1682
92
1854
125
initial-uncertainty-max
initial-uncertainty-max
0
1
0.6
0.01
1
NIL
HORIZONTAL

SLIDER
1682
125
1854
158
interaction-partners
interaction-partners
1
20
2.0
1
1
NIL
HORIZONTAL

SLIDER
1682
190
1854
223
policy-threshold
policy-threshold
0.5
1
0.55
0.01
1
NIL
HORIZONTAL

SLIDER
1682
157
1854
190
norm-adoption-threshold
norm-adoption-threshold
0.5
1
0.83
0.01
1
NIL
HORIZONTAL

SLIDER
1682
223
1854
256
lobby-effectiveness
lobby-effectiveness
0
1
0.5
0.1
1
NIL
HORIZONTAL

SLIDER
1459
295
1656
328
criminal-susceptibility
criminal-susceptibility
0
1
0.0
0.01
1
NIL
HORIZONTAL

SLIDER
1682
256
1854
289
election-period
election-period
0
10
4.0
1
1
year
HORIZONTAL

SLIDER
1681
310
1853
343
emigration-factor
emigration-factor
0
1
0.1
0.01
1
/y
HORIZONTAL

SLIDER
1681
343
1853
376
bad-air-limit
bad-air-limit
0
200000
30000.0
10000
1
pigs/year
HORIZONTAL

TEXTBOX
1686
293
1754
311
LIVELIHOOD
11
0.0
1

PLOT
1108
496
1447
646
political parties
years
% votes
0.0
50.0
0.0
100.0
true
true
"" ""
PENS
"local / economy oriented" 1.0 0 -16777216 true "" "plot 100 * [votes] of one-of political-parties with\n [social-responsibility-orientation = 0\n  and local-orientation = 1]\n   / sum [votes] of political-parties"
"cosmopolitan / economy" 1.0 0 -13345367 true "" "plot 100 * [votes] of one-of political-parties with\n [social-responsibility-orientation = 0\n  and local-orientation = 0]\n   / sum [votes] of political-parties"
"local / social responsibility" 1.0 0 -2674135 true "" "plot 100 * [votes] of one-of political-parties with\n [social-responsibility-orientation = 1\n and local-orientation = 1]\n   / sum [votes] of political-parties"
"cosmopolitan / social respon." 1.0 0 -10899396 true "" "plot 100 * [votes] of one-of political-parties with\n [social-responsibility-orientation = 1\n  and local-orientation = 0]\n   / sum [votes] of political-parties"

PLOT
1108
346
1447
496
public opinion
years
opinion
0.0
50.0
0.0
1.0
true
true
"" ""
PENS
"invest in livestock" 1.0 0 -16777216 true "" "plot item 0 public-opinion"
"license required for livestock" 1.0 0 -2064490 true "" "plot item 10 public-opinion"
"freeze production capacity" 1.0 0 -13345367 true "" "plot item 12 public-opinion"
"no more licences" 1.0 0 -2674135 true "" "plot item 13 public-opinion"
"not near the city" 1.0 0 -13840069 true "" "plot item 11 public-opinion"
"indifferent" 1.0 0 -7500403 true "" "plot 0.5"

MONITOR
1668
606
1790
651
total_tech_emigration
total_tech_emigration
0
1
11

MONITOR
1668
561
1790
606
tech_employment
tech_employment
0
1
11

MONITOR
1668
516
1790
561
agri_employment
agri_employment
0
1
11

MONITOR
1668
426
1790
471
annual_production
annual_production
0
1
11

MONITOR
1668
381
1790
426
farms
farms
0
1
11

MONITOR
1668
471
1790
516
farm_income
farm_income
0
1
11

@#$#@#$#@
## WHAT IS IT?

This section could give a general understanding of what the model is trying to show or explain.

## HOW IT WORKS

This section could explain what rules the agents use to create the overall behavior of the model.

## HOW TO USE IT

This section could explain how to use the model, including a description of each of the items in the interface tab.

## THINGS TO NOTICE

This section could give some ideas of things for the user to notice while running the model.

## THINGS TO TRY

This section could give some ideas of things for the user to try to do (move sliders, switches, etc.) with the model.

## EXTENDING THE MODEL

This section could give some ideas of things to add or change in the procedures tab to make the model more complicated, detailed, accurate, etc.

## NETLOGO FEATURES

This section could point out any especially interesting or unusual features of NetLogo that the model makes use of, particularly in the Procedures tab.  It might also point out places where workarounds were needed because of missing features.

## RELATED MODELS

This section could give the names of models in the NetLogo Models Library or elsewhere which are of related interest.

## CREDITS AND REFERENCES

This section could contain a reference to the model's URL on the web if it has one, as well as any other necessary credits or references.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

farm
false
0
Rectangle -7500403 true true 30 105 90 255
Circle -7500403 true true 30 75 58
Polygon -7500403 true true 120 150 180 105 255 150 255 255 120 255
Rectangle -16777216 true false 150 180 225 255

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
0
Rectangle -7500403 true true 151 225 180 285
Rectangle -7500403 true true 47 225 75 285
Rectangle -7500403 true true 15 75 210 225
Circle -7500403 true true 135 75 150
Circle -16777216 true false 165 76 116

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.0.4
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="experiment-default" repetitions="32" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>farms</metric>
    <metric>annual_production</metric>
    <metric>farm_income</metric>
    <metric>agri_employment</metric>
    <metric>tech_employment</metric>
    <metric>total_tech_emigration</metric>
    <enumeratedValueSet variable="policy-threshold">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="norm-adoption-threshold">
      <value value="0.83"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-salary-tech">
      <value value="50000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="not-near-the-city">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="agri-complex-employment">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tech-industry-growth">
      <value value="3.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="village-cost-of-living">
      <value value="20000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="country-cost-of-living">
      <value value="30000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-initial-capacity">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="freeze-production-capacity">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="emigration-factor">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="interaction-partners">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-uncertainty-max">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="lobby-effectiveness">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-time">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="investment-cost">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="external-policy-effect">
      <value value="0.042"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="criminal-susceptibility">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farm-estate-value">
      <value value="1000000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="election-period">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="no-more-licences">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="opinion-dynamics-mu">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bad-air-limit">
      <value value="50000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="price-lower-bound">
      <value value="110"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-input-cost">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="city-cost-of-living">
      <value value="25000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-salary-agri">
      <value value="40000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="price-upper-bound">
      <value value="130"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-uncertainty-min">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="licence-required-for-livestock">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="outbreak-frequency">
      <value value="0.04"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="auto-politics">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment-stable-price120" repetitions="8" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>farms</metric>
    <metric>annual_production</metric>
    <metric>farm_income</metric>
    <metric>agri_employment</metric>
    <metric>tech_employment</metric>
    <metric>total_tech_emigration</metric>
    <enumeratedValueSet variable="policy-threshold">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="norm-adoption-threshold">
      <value value="0.83"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-salary-tech">
      <value value="50000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="not-near-the-city">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="agri-complex-employment">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tech-industry-growth">
      <value value="3.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="village-cost-of-living">
      <value value="20000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="country-cost-of-living">
      <value value="30000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-initial-capacity">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="freeze-production-capacity">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="emigration-factor">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="interaction-partners">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-uncertainty-max">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="lobby-effectiveness">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-time">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="investment-cost">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="external-policy-effect">
      <value value="0.042"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="criminal-susceptibility">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farm-estate-value">
      <value value="1000000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="election-period">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="no-more-licences">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="opinion-dynamics-mu">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bad-air-limit">
      <value value="50000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="price-lower-bound">
      <value value="120"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-input-cost">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="city-cost-of-living">
      <value value="25000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-salary-agri">
      <value value="40000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="price-upper-bound">
      <value value="120"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-uncertainty-min">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="licence-required-for-livestock">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="outbreak-frequency">
      <value value="0.04"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="auto-politics">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment-pig-production-sensitivity" repetitions="32" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>farms</metric>
    <metric>annual_production</metric>
    <metric>farm_income</metric>
    <metric>agri_employment</metric>
    <metric>tech_employment</metric>
    <metric>total_tech_emigration</metric>
    <enumeratedValueSet variable="policy-threshold">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="norm-adoption-threshold">
      <value value="0.83"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-salary-tech">
      <value value="50000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="not-near-the-city">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="agri-complex-employment">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tech-industry-growth">
      <value value="3.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="village-cost-of-living">
      <value value="20000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="country-cost-of-living">
      <value value="27000"/>
      <value value="33000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-initial-capacity">
      <value value="450"/>
      <value value="550"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="freeze-production-capacity">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="emigration-factor">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="interaction-partners">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-uncertainty-max">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="lobby-effectiveness">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-time">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="investment-cost">
      <value value="180"/>
      <value value="220"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="external-policy-effect">
      <value value="0.037"/>
      <value value="0.047"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="criminal-susceptibility">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farm-estate-value">
      <value value="1000000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="election-period">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="no-more-licences">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="opinion-dynamics-mu">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bad-air-limit">
      <value value="50000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="price-lower-bound">
      <value value="110"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-input-cost">
      <value value="65"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="city-cost-of-living">
      <value value="25000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-salary-agri">
      <value value="40000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="price-upper-bound">
      <value value="130"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-uncertainty-min">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="licence-required-for-livestock">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="outbreak-frequency">
      <value value="0.04"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="auto-politics">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment-politics-policy-threshold" repetitions="4" sequentialRunOrder="false" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>farms</metric>
    <metric>annual_production</metric>
    <metric>farm_income</metric>
    <metric>agri_employment</metric>
    <metric>tech_employment</metric>
    <metric>total_tech_emigration</metric>
    <metric>licence-required-for-livestock</metric>
    <metric>freeze-production-capacity</metric>
    <metric>no-more-licences</metric>
    <metric>not-near-the-city</metric>
    <enumeratedValueSet variable="policy-threshold">
      <value value="0.5"/>
      <value value="0.52"/>
      <value value="0.54"/>
      <value value="0.56"/>
      <value value="0.58"/>
      <value value="0.6"/>
      <value value="0.62"/>
      <value value="0.64"/>
      <value value="0.66"/>
      <value value="0.68"/>
      <value value="0.7"/>
      <value value="0.72"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="norm-adoption-threshold">
      <value value="0.83"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-salary-tech">
      <value value="50000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="not-near-the-city">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="agri-complex-employment">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tech-industry-growth">
      <value value="3.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="village-cost-of-living">
      <value value="20000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="country-cost-of-living">
      <value value="30000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-initial-capacity">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="freeze-production-capacity">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="emigration-factor">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="interaction-partners">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-uncertainty-max">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="lobby-effectiveness">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-time">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="investment-cost">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="external-policy-effect">
      <value value="0.042"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="criminal-susceptibility">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farm-estate-value">
      <value value="1000000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="election-period">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="no-more-licences">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="opinion-dynamics-mu">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bad-air-limit">
      <value value="30000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="price-lower-bound">
      <value value="110"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-input-cost">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="city-cost-of-living">
      <value value="25000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-salary-agri">
      <value value="40000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="price-upper-bound">
      <value value="130"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-uncertainty-min">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="licence-required-for-livestock">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="outbreak-frequency">
      <value value="0.04"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="auto-politics">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment-politics-lobby-eff" repetitions="3" sequentialRunOrder="false" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>farms</metric>
    <metric>annual_production</metric>
    <metric>farm_income</metric>
    <metric>agri_employment</metric>
    <metric>tech_employment</metric>
    <metric>total_tech_emigration</metric>
    <metric>licence-required-for-livestock</metric>
    <metric>freeze-production-capacity</metric>
    <metric>no-more-licences</metric>
    <metric>not-near-the-city</metric>
    <enumeratedValueSet variable="policy-threshold">
      <value value="0.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="norm-adoption-threshold">
      <value value="0.83"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-salary-tech">
      <value value="50000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="not-near-the-city">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="agri-complex-employment">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tech-industry-growth">
      <value value="3.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="village-cost-of-living">
      <value value="20000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="country-cost-of-living">
      <value value="30000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-initial-capacity">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="freeze-production-capacity">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="emigration-factor">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="interaction-partners">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-uncertainty-max">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="lobby-effectiveness">
      <value value="0.2"/>
      <value value="0.22"/>
      <value value="0.24"/>
      <value value="0.26"/>
      <value value="0.28"/>
      <value value="0.3"/>
      <value value="0.32"/>
      <value value="0.34"/>
      <value value="0.36"/>
      <value value="0.38"/>
      <value value="0.4"/>
      <value value="0.42"/>
      <value value="0.44"/>
      <value value="0.46"/>
      <value value="0.48"/>
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-time">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="investment-cost">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="external-policy-effect">
      <value value="0.042"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="criminal-susceptibility">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farm-estate-value">
      <value value="1000000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="election-period">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="no-more-licences">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="opinion-dynamics-mu">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bad-air-limit">
      <value value="30000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="price-lower-bound">
      <value value="110"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-input-cost">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="city-cost-of-living">
      <value value="25000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-salary-agri">
      <value value="40000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="price-upper-bound">
      <value value="130"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-uncertainty-min">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="licence-required-for-livestock">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="outbreak-frequency">
      <value value="0.04"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="auto-politics">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment-politics-mu" repetitions="4" sequentialRunOrder="false" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>farms</metric>
    <metric>annual_production</metric>
    <metric>farm_income</metric>
    <metric>agri_employment</metric>
    <metric>tech_employment</metric>
    <metric>total_tech_emigration</metric>
    <metric>licence-required-for-livestock</metric>
    <metric>freeze-production-capacity</metric>
    <metric>no-more-licences</metric>
    <metric>not-near-the-city</metric>
    <enumeratedValueSet variable="policy-threshold">
      <value value="0.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="norm-adoption-threshold">
      <value value="0.83"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-salary-tech">
      <value value="50000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="not-near-the-city">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="agri-complex-employment">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tech-industry-growth">
      <value value="3.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="village-cost-of-living">
      <value value="20000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="country-cost-of-living">
      <value value="30000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-initial-capacity">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="freeze-production-capacity">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="emigration-factor">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="interaction-partners">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-uncertainty-max">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="lobby-effectiveness">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-time">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="investment-cost">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="external-policy-effect">
      <value value="0.042"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="criminal-susceptibility">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farm-estate-value">
      <value value="1000000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="election-period">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="no-more-licences">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="opinion-dynamics-mu">
      <value value="0.1"/>
      <value value="0.12"/>
      <value value="0.14"/>
      <value value="0.16"/>
      <value value="0.18"/>
      <value value="0.2"/>
      <value value="0.22"/>
      <value value="0.24"/>
      <value value="0.26"/>
      <value value="0.28"/>
      <value value="0.3"/>
      <value value="0.32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bad-air-limit">
      <value value="30000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="price-lower-bound">
      <value value="110"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-input-cost">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="city-cost-of-living">
      <value value="25000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-salary-agri">
      <value value="40000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="price-upper-bound">
      <value value="130"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-uncertainty-min">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="licence-required-for-livestock">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="outbreak-frequency">
      <value value="0.04"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="auto-politics">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment-politics-uncertainty" repetitions="1" sequentialRunOrder="false" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>farms</metric>
    <metric>annual_production</metric>
    <metric>farm_income</metric>
    <metric>agri_employment</metric>
    <metric>tech_employment</metric>
    <metric>total_tech_emigration</metric>
    <metric>licence-required-for-livestock</metric>
    <metric>freeze-production-capacity</metric>
    <metric>no-more-licences</metric>
    <metric>not-near-the-city</metric>
    <enumeratedValueSet variable="policy-threshold">
      <value value="0.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="norm-adoption-threshold">
      <value value="0.83"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-salary-tech">
      <value value="50000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="not-near-the-city">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="agri-complex-employment">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tech-industry-growth">
      <value value="3.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="village-cost-of-living">
      <value value="20000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="country-cost-of-living">
      <value value="30000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-initial-capacity">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="freeze-production-capacity">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="emigration-factor">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="interaction-partners">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-uncertainty-max">
      <value value="0.51"/>
      <value value="0.55"/>
      <value value="0.6"/>
      <value value="0.64"/>
      <value value="0.67"/>
      <value value="0.69"/>
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="lobby-effectiveness">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-time">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="investment-cost">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="external-policy-effect">
      <value value="0.042"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="criminal-susceptibility">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farm-estate-value">
      <value value="1000000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="election-period">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="no-more-licences">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="opinion-dynamics-mu">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bad-air-limit">
      <value value="30000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="price-lower-bound">
      <value value="110"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-input-cost">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="city-cost-of-living">
      <value value="25000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-salary-agri">
      <value value="40000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="price-upper-bound">
      <value value="130"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-uncertainty-min">
      <value value="0.3"/>
      <value value="0.31"/>
      <value value="0.33"/>
      <value value="0.36"/>
      <value value="0.4"/>
      <value value="0.45"/>
      <value value="0.49"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="licence-required-for-livestock">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="outbreak-frequency">
      <value value="0.04"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="auto-politics">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment-politics-interactions" repetitions="7" sequentialRunOrder="false" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>farms</metric>
    <metric>annual_production</metric>
    <metric>farm_income</metric>
    <metric>agri_employment</metric>
    <metric>tech_employment</metric>
    <metric>total_tech_emigration</metric>
    <metric>licence-required-for-livestock</metric>
    <metric>freeze-production-capacity</metric>
    <metric>no-more-licences</metric>
    <metric>not-near-the-city</metric>
    <enumeratedValueSet variable="policy-threshold">
      <value value="0.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="norm-adoption-threshold">
      <value value="0.83"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-salary-tech">
      <value value="50000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="not-near-the-city">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="agri-complex-employment">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tech-industry-growth">
      <value value="3.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="village-cost-of-living">
      <value value="20000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="country-cost-of-living">
      <value value="30000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-initial-capacity">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="freeze-production-capacity">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="emigration-factor">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="interaction-partners">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
      <value value="5"/>
      <value value="6"/>
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-uncertainty-max">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="lobby-effectiveness">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-time">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="investment-cost">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="external-policy-effect">
      <value value="0.042"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="criminal-susceptibility">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="farm-estate-value">
      <value value="1000000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="election-period">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="no-more-licences">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="opinion-dynamics-mu">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bad-air-limit">
      <value value="30000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="price-lower-bound">
      <value value="110"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-input-cost">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="city-cost-of-living">
      <value value="25000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-salary-agri">
      <value value="40000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="price-upper-bound">
      <value value="130"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-uncertainty-min">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="licence-required-for-livestock">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="outbreak-frequency">
      <value value="0.04"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="auto-politics">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
